photosgallery/viewframework/medialists/src/glxlistwindow.cpp
branchRCL_3
changeset 47 f9e827349359
parent 30 a60acebbbd9d
--- a/photosgallery/viewframework/medialists/src/glxlistwindow.cpp	Wed Jun 09 09:41:51 2010 +0300
+++ b/photosgallery/viewframework/medialists/src/glxlistwindow.cpp	Mon Jun 21 15:40:32 2010 +0300
@@ -52,7 +52,7 @@
         }
         
     /** Preparet the window to accept items */
-    void Initialize( const CGlxListWindow::TRange& aRange, TInt aTotalSize )
+    void InitializeL( const CGlxListWindow::TRange& aRange, TInt aTotalSize )
         {
         __TEST_INVARIANT;
         
@@ -68,7 +68,7 @@
         for ( TInt i = iObjects.Count(); i < aRange.iLength; i++ ) 
             {
             // Append cannot fail since reservation has been made
-            ( void ) iObjects.Append( NULL );
+            ( void ) iObjects.AppendL( NULL );
             }
 
         // remove unnecessary pointers
@@ -276,12 +276,12 @@
 // Cleans up remaining objects in the window
 // -----------------------------------------------------------------------------
 //
-EXPORT_C void CGlxListWindow::Cleanup() 
+EXPORT_C void CGlxListWindow::CleanupL() 
 	{
-	TRACER("CGlxListWindow::Cleanup");
+	TRACER("CGlxListWindow::CleanupL");
 	
     // make the window empty. this will clean up all remaining objects.
-    Update( TChange( KErrNotFound, 0, EChangeObjectsRemoved, 0, iWindow->TotalSize() - 1 ) );
+    UpdateL( TChange( KErrNotFound, 0, EChangeObjectsRemoved, 0, iWindow->TotalSize() - 1 ) );
 	}
 	
 // -----------------------------------------------------------------------------
@@ -326,10 +326,10 @@
     for ( TInt i = iWindow->Size() + iUnusedObjects.Count(); i < maxObjectCount; i++ )
         {
         // cannot fail since reservation made above
-        ( void ) iUnusedObjects.Append( iObjectFactory.CreateObjectL() );
+        ( void )iUnusedObjects.AppendL( iObjectFactory.CreateObjectL() );
         }
 	
-	Update( TChange( aFocusIndex, aTotalSize, EChangeNone, 0, 0 ) );
+	UpdateL( TChange( aFocusIndex, aTotalSize, EChangeNone, 0, 0 ) );
 	}
     
 // -----------------------------------------------------------------------------
@@ -347,38 +347,38 @@
 // SetFocusIndexL
 // -----------------------------------------------------------------------------
 // DEPRICATED
-EXPORT_C void CGlxListWindow::SetFocusIndex( TInt aFocusIndex ) 
+EXPORT_C void CGlxListWindow::SetFocusIndexL( TInt aFocusIndex ) 
 	{
-	TRACER("CGlxListWindow::SetFocusIndex");
+	TRACER("CGlxListWindow::SetFocusIndexL");
 	
-	SetFocusIndex( aFocusIndex, iWindow->TotalSize() );
+	SetFocusIndexL( aFocusIndex, iWindow->TotalSize() );
 	}
 	
 // -----------------------------------------------------------------------------
 // SetFocusIndexL
 // -----------------------------------------------------------------------------
 //
-EXPORT_C void CGlxListWindow::SetFocusIndex( TInt aFocusIndex, TInt aTotalSize ) 
+EXPORT_C void CGlxListWindow::SetFocusIndexL( TInt aFocusIndex, TInt aTotalSize ) 
 	{
-	TRACER("CGlxListWindow::SetFocusIndex");
+	TRACER("CGlxListWindow::SetFocusIndexL");
 	
 	__ASSERT_DEBUG( ( 0 <= aFocusIndex && aFocusIndex < aTotalSize ) ||
                     ( KErrNotFound == aFocusIndex && 0 == aTotalSize ), 
                     Panic( EGlxPanicIllegalArgument ) );
     __TEST_INVARIANT;
     
-	Update( TChange( aFocusIndex, aTotalSize, EChangeNone, 0, 0 ) );
+	UpdateL( TChange( aFocusIndex, aTotalSize, EChangeNone, 0, 0 ) );
     
     __TEST_INVARIANT;
 	}
 		
 // -----------------------------------------------------------------------------
-// AddObjects
+// AddObjectsL
 // -----------------------------------------------------------------------------
 // DEPRICATED
-EXPORT_C void CGlxListWindow::AddObjects( TInt aFirstNewIndex, TInt aLastNewIndex ) 
+EXPORT_C void CGlxListWindow::AddObjectsL( TInt aFirstNewIndex, TInt aLastNewIndex ) 
 	{
-	TRACER("CGlxListWindow::AddObjects");
+	TRACER("CGlxListWindow::AddObjectsL");
 	
 	TInt newItemCount = aLastNewIndex - aFirstNewIndex + 1;
 	TInt newTotalSize = iWindow->TotalSize() + newItemCount;
@@ -398,17 +398,17 @@
 		newFocusIndex += newItemCount;
 		}
 		
-    AddObjects( newFocusIndex, newTotalSize, aFirstNewIndex, aLastNewIndex );
+    AddObjectsL( newFocusIndex, newTotalSize, aFirstNewIndex, aLastNewIndex );
 	}
 		
 // -----------------------------------------------------------------------------
-// AddObjects
+// AddObjectsL
 // -----------------------------------------------------------------------------
 //
-EXPORT_C void CGlxListWindow::AddObjects( TInt aFocusIndex, 
+EXPORT_C void CGlxListWindow::AddObjectsL( TInt aFocusIndex, 
         TInt aTotalSize, TInt aFirstNewIndex, TInt aLastNewIndex ) 
 	{
-	TRACER("CGlxListWindow::AddObjects");
+	TRACER("CGlxListWindow::AddObjectsL");
 	
     __ASSERT_DEBUG( 0 <= aFirstNewIndex && aFirstNewIndex <= aLastNewIndex && 
                     aLastNewIndex < aTotalSize &&
@@ -416,19 +416,19 @@
                     Panic( EGlxPanicIllegalArgument ) ); 
     __TEST_INVARIANT;
 	
-	Update( TChange( aFocusIndex, aTotalSize, EChangeObjectsAdded, 
+	UpdateL( TChange( aFocusIndex, aTotalSize, EChangeObjectsAdded, 
         aFirstNewIndex, aLastNewIndex ) );
 		
     __TEST_INVARIANT;
 	}
 	
 // -----------------------------------------------------------------------------
-// RemoveObjects
+// RemoveObjectsL
 // -----------------------------------------------------------------------------
 // DEPRICATED
-EXPORT_C void CGlxListWindow::RemoveObjects( TInt aFirstRemovedIndex, TInt aLastRemovedIndex ) 
+EXPORT_C void CGlxListWindow::RemoveObjectsL( TInt aFirstRemovedIndex, TInt aLastRemovedIndex ) 
 	{
-	TRACER("CGlxListWindow::RemoveObjects");
+	TRACER("CGlxListWindow::RemoveObjectsL");
 	
 	TInt itemsRemovedCount = aLastRemovedIndex - aFirstRemovedIndex + 1;
 	TInt newTotalSize = iWindow->TotalSize() - itemsRemovedCount;
@@ -460,17 +460,17 @@
 	    	}
 	    }
 
-	RemoveObjects( newFocusIndex, newTotalSize, aFirstRemovedIndex, aLastRemovedIndex );
+	RemoveObjectsL( newFocusIndex, newTotalSize, aFirstRemovedIndex, aLastRemovedIndex );
 	}	
 
 // -----------------------------------------------------------------------------
-// RemoveObjects
+// RemoveObjectsL
 // -----------------------------------------------------------------------------
 //	
-EXPORT_C void CGlxListWindow::RemoveObjects( TInt aFocusIndex, 
+EXPORT_C void CGlxListWindow::RemoveObjectsL( TInt aFocusIndex, 
         TInt aTotalSize, TInt aFirstRemovedIndex, TInt aLastRemovedIndex ) 
 	{
-	TRACER("CGlxListWindow::RemoveObjects");
+	TRACER("CGlxListWindow::RemoveObjectsL");
 	
     __ASSERT_DEBUG( 0 <= aFirstRemovedIndex && aFirstRemovedIndex <= aLastRemovedIndex &&
                     ( ( 0 <= aFocusIndex && aFocusIndex < aTotalSize ) || 
@@ -478,19 +478,19 @@
                     Panic( EGlxPanicIllegalArgument ) ); 
     __TEST_INVARIANT;
     
-	Update( TChange( aFocusIndex, aTotalSize, EChangeObjectsRemoved, 
+	UpdateL( TChange( aFocusIndex, aTotalSize, EChangeObjectsRemoved, 
         aFirstRemovedIndex, aLastRemovedIndex ) );
 
     __TEST_INVARIANT;
 	}	
     
 // -----------------------------------------------------------------------------
-// Update
+// UpdateL
 // -----------------------------------------------------------------------------
 //
-void CGlxListWindow::Update( const TChange& aChange )
+void CGlxListWindow::UpdateL( const TChange& aChange )
 	{
-	TRACER("CGlxListWindow::Update");
+	TRACER("CGlxListWindow::UpdateL");
 	
     // (in a list of:  |abcdefghijklm|
     // iWindow:        |----efghi----|
@@ -499,14 +499,14 @@
     //                      is shorter than max window length)
     
     // Prepare the working window to accept objects
-    iWorkingWindow->Initialize( Range( aChange ), aChange.iNewTotalSize );
+    iWorkingWindow->InitializeL( Range( aChange ), aChange.iNewTotalSize );
 
     // iWindow:        |----efghi----|
     // iWorkingWindow: |------00000--|
     // iUnusedObjects: XXX 
     
     // move unused objects to pool, and reusable objects to working window
-    PopulateExistingAndUnuseOld( aChange );
+    PopulateExistingAndUnuseOldL( aChange );
 
     // iWindow:        |----efghi----|
     // iWorkingWindow: |------ghi00--|
@@ -533,12 +533,12 @@
 	}
     
 // -----------------------------------------------------------------------------
-// PopulateExistingAndUnuseOld
+// PopulateExistingAndUnuseOldL
 // -----------------------------------------------------------------------------
 //	
-void CGlxListWindow::PopulateExistingAndUnuseOld( const TChange& aChange ) 
+void CGlxListWindow::PopulateExistingAndUnuseOldL( const TChange& aChange ) 
     {
-    TRACER("CGlxListWindow::PopulateExistingAndUnuseOld");
+    TRACER("CGlxListWindow::PopulateExistingAndUnuseOldL");
     
     // move objects that are needed after the change into the working window, 
     // and objects that are not needed into the object pool
@@ -562,11 +562,11 @@
             iObjectFactory.CleanupObject( index, *( *iWindow )[ index ] );
             // add the object to the unused objects pool
             // cannot fail since reservation made
-            ( void ) iUnusedObjects.Append( ( *iWindow )[ index ] );
+            ( void )iUnusedObjects.AppendL( ( *iWindow )[ index ] );
             }
             
         // clear the pointer in the existing window. it is not strictly necessary
         // to do here, but saves a loop from doing it in CGlxDataWindow::Initialize
         ( *iWindow )[ index ] = NULL;
         }
     }
@@ -562,11 +562,11 @@
             
         // clear the pointer in the existing window. it is not strictly necessary
-        // to do here, but saves a loop from doing it in CGlxDataWindow::Initialize
+        // to do here, but saves a loop from doing it in CGlxDataWindow::InitializeL
         ( *iWindow )[ index ] = NULL;
         }